OC.L10N.register(
    "comments",
    {
    "Type in a new comment..." : "Skriv en ny kommentar",
    "Delete comment" : "Radera kommentar",
    "Post" : "Skicka",
    "Cancel" : "Avbryt",
    "Edit comment" : "Redigera kommentar",
    "[Deleted user]" : "[Raderad användare]",
    "Comments" : "Kommentarer",
    "No other comments available" : "Inga andra kommentarer tillgängliga",
    "More comments..." : "Fler kommentarter,,,",
    "Save" : "Spara",
    "Allowed characters {count} of {max}" : "Tillåtet antal tecken {count} av {max}",
    "{count} unread comments" : "{count} olästa kommentarer",
    "Comment" : "Kommentar",
    "<strong>Comments</strong> for files <em>(always listed in stream)</em>" : "<strong>Kommentarer</strong> för filer <em>(listad alltid i flödet)</em>",
    "You commented" : "Du kommenterade",
    "%1$s commented" : "%1$s har kommenterat",
    "You commented on %2$s" : "Du kommenterade %2$s",
    "%1$s commented on %2$s" : "%1$s kommenterade på %2$s"
},
"nplurals=2; plural=(n != 1);");
